@@ -236,4 +236,4 @@ class SubProcessCompressor(CompressorBase):
             raise CompressorError(stderr)
         if self.verbose:
             print(stderr)
-        return stdout
+        return force_text(stdout)
