@@ -13,6 +13,7 @@ SITE_ID = 1
 INSTALLED_APPS = [
     'django.contrib.contenttypes',
     'django.contrib.sites',
+    'django.contrib.sessions',
     'django.contrib.staticfiles',
     'django.contrib.auth',
     'django.contrib.admin',
@@ -20,6 +21,8 @@ INSTALLED_APPS = [
     'tests',
 ]
 
+ROOT_URLCONF = 'tests.urls'
+
 MEDIA_URL = '/media/'
 
 MEDIA_ROOT = local_path('media')
